<?php

namespace Drupal\last_tweets\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\last_tweets\LastTweetsHelper;

/**
 * Provides a 'LastTweetsBlock' block.
 *
 * @Block(
 *  id = "last_tweets_block",
 *  admin_label = @Translation("Last tweets block"),
 * )
 */
class LastTweetsBlock extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form['twitter_limit'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Twitter limit'),
      '#description' => $this->t('Set the number of tweets. Default = 3.'),
      '#default_value' => isset($this->configuration['twitter_limit']) ? $this->configuration['twitter_limit'] : 3,
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    $this->configuration['twitter_limit'] = $form_state->getValue('twitter_limit');
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $twitter_limit = $this->configuration['twitter_limit'];
    $lastTweetsHtml = LastTweetsHelper::getLastTweets($twitter_limit);
    $build = [];
    $build['last_tweets'] = $lastTweetsHtml;
    $build['#attached'] = [
      'library' => [
        'last_tweets/last-tweets',
      ],
    ];
    return $build;
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheMaxAge() {
    return 0;
  }

}
